@@ -30,11 +30,12 @@ import shutil
 import numpy
 import unittest
 
-from casatools import ctsys, ms, table
-from casatasks import importfitsidi, casalog
+from casatools import ctsys, image, ms, table
+from casatasks import importfitsidi, casalog, tclean
 
 _ms = ms( )
 _tb = table( )
+_ia = image( )
 
 logpath = casalog.logfile()
 
@@ -55,6 +56,9 @@ my_dataset_names = ['n09q2_1_1-shortened.IDI1',
 # name of the resulting MS
 msname = my_dataset_names[0]+'.ms'
 
+# name of images produced by this test
+imgname = 'n09q2'
+
 def checktable(thename, theexpectation):
     global msname, myname
     _tb.open(msname+"/"+thename)
@@ -121,6 +125,7 @@ class test_importfitsidi(unittest.TestCase):
             os.remove(fname)
         shutil.rmtree(msname,ignore_errors=True)
         shutil.rmtree(msname+'.flagversions',ignore_errors=True)
+        os.system('rm -rf ' + imgname+'*')
         
     def test1(self):
         '''fitsidi-import: Test good input'''
@@ -1341,6 +1346,86 @@ class test_importfitsidi(unittest.TestCase):
             success = ('Data was correlated with HANNING taper' in logf.read())
         self.assertTrue(success)
 
+    def test11(self):
+        '''fitsidi-import: Test default reference frame'''
+        retValue = {'success': True, 'msgs': "", 'error_msgs': '' }
+
+        self.res = importfitsidi(my_dataset_names[0], msname,  scanreindexgap_s=100., constobsid=True)
+        print(myname, ": Success! Now checking output ...")
+        try:
+            _tb.open(msname+'/FIELD')
+        except:
+            print(myname, ": Error  Cannot open FIELD table")
+            retValue['success']=False
+            retValue['error_msgs']=retValue['error_msgs']+'Cannot open FIELD table '
+        else:
+            for colname in ['DELAY_DIR', 'PHASE_DIR', 'REFERENCE_DIR']:
+                kwds = _tb.getcolkeywords(colname)
+                if not kwds['MEASINFO']['Ref'] == 'ICRS':
+                    print(myname, ": Incorrect MEASINFO")
+                    retValue['success']=False
+                    retValue['error_msgs']=retValue['error_msgs']+msname+' incorrect MEASINFO'
+            _tb.close()
+
+            # check that a FITS image produced from the imported data
+            # is tagged with the correct reference frame
+            try:
+                tclean(vis=msname, imagename=imgname, cell='1.0arcsec')
+                _ia.open(imgname+'.image')
+            except:
+                print(myname, ": Error  Cannot open image", imgname+'.psf')
+                retValue['success']=False
+                retValue['error_msgs']=retValue['error_msgs']+'Cannot open image '+imgname+'.image'
+            else:
+                kwds = _ia.fitsheader()
+                if not kwds['RADESYS'] == 'ICRS    ':
+                    print(myname, ": Incorrect RADESYS")
+                    retValue['success']=False
+                    retValue['error_msgs']=retValue['error_msgs']+msname+' incorrect RADESYS'
+            _ia.close()
+
+        self.assertTrue(retValue['success'])
+
+    def test12(self):
+        '''fitsidi-import: Test overriding reference frame'''
+        retValue = {'success': True, 'msgs': "", 'error_msgs': '' }
+
+        self.res = importfitsidi(my_dataset_names[0], msname,  scanreindexgap_s=100., constobsid=True, coordframe='J2000')
+        print(myname, ": Success! Now checking output ...")
+        try:
+            _tb.open(msname+'/FIELD')
+        except:
+            print(myname, ": Error  Cannot open FIELD table")
+            retValue['success']=False
+            retValue['error_msgs']=retValue['error_msgs']+'Cannot open FIELD table '
+        else:
+            for colname in ['DELAY_DIR', 'PHASE_DIR', 'REFERENCE_DIR']:
+                kwds = _tb.getcolkeywords(colname)
+                if not kwds['MEASINFO']['Ref'] == 'J2000':
+                    print(myname, ": Incorrect MEASINFO")
+                    retValue['success']=False
+                    retValue['error_msgs']=retValue['error_msgs']+msname+' incorrect MEASINFO'
+            _tb.close()
+
+            # check that a FITS image produced from the imported data
+            # is tagged with the correct reference frame
+            try:
+                tclean(vis=msname, imagename=imgname, cell='1.0arcsec')
+                _ia.open(imgname+'.image')
+            except:
+                print(myname, ": Error  Cannot open image", imgname+'.psf')
+                retValue['success']=False
+                retValue['error_msgs']=retValue['error_msgs']+'Cannot open image '+imgname+'.image'
+            else:
+                kwds = _ia.fitsheader()
+                if not kwds['RADESYS'] == 'FK5     ':
+                    print(myname, ": Incorrect RADESYS")
+                    retValue['success']=False
+                    retValue['error_msgs']=retValue['error_msgs']+msname+' incorrect RADESYS'
+            _ia.close()
+
+        self.assertTrue(retValue['success'])
+
 
 if __name__ == '__main__':
     unittest.main()
